@@ -542,7 +542,11 @@ class Model(WithMemoization, metaclass=ContextMeta):
         name="",
         coords=None,
         check_bounds=True,
+        *,
+        aesara_config=None,
+        model=None,
     ):
+        del aesara_config, model  # used in __new__
         self.name = self._validate_name(name)
         self.check_bounds = check_bounds
 
